@@ -30,7 +30,8 @@ class RKAdmin:
         graph_builder_url = graph_builder_url.rstrip('/')
         log.info(f"Connecting to Graph Builder: {graph_builder_url}")
         self.graph_builder_client = RequestHelper(graph_builder_url, timeout_sec=timeout_sec, insecure=insecure,
-                                                  user_auth=user_auth, puc_auth=puc_auth)
+                                                  user_auth=user_auth, puc_auth=puc_auth,
+                                                  user_agent=f'recordkeeper-client-{self.receiver_client.get_version()}')
 
     def check_connections(self) -> Tuple[str, bool]:
         msg, ok = self.graph_builder_client.get("/info")
@@ -64,6 +65,25 @@ class RKAdmin:
             return f"flushing queue failed: {text}", False
         return f"flushing queue finished, in {total_flush_time:.2f}s", True
 
+    def graph_verify(self) -> Tuple[str, bool]:
+        """
+        Starts sql vs graph comparison, and returns result as string with newlines.
+        :return: first element: error message or 'OK'
+                 second element: True for success, False for error
+        """
+        text, ok = self.graph_builder_client.post("/verify", "{}")
+        if not ok:
+            return f"Verifying integrity failed: {text}", False
+        return text, True
+
+    def get_graph_info(self) -> Tuple[str, bool]:
+        """
+        Returns json with fields as in GraphBuilderInfo class - the GB state. Use `deserialize_graph_builder_info` for easy parsing.
+        :return: check class description
+        """
+        text, ok = self.graph_builder_client.get("/info")
+        return text, ok
+
     def clean_dbs(self) -> Tuple[str, bool]:
         """
         :return: first element: error message or 'OK'
@@ -74,6 +94,22 @@ class RKAdmin:
             return f"Cleaning db failed: {text}", False
         return 'OK', True
 
+    def get_pem(self, pem_id: str) -> Tuple[Optional[PEM], str, bool]:
+        """
+        Returns pem from sql db.
+        :param pem_id: UUID, should be in hex format.
+        :return: PEM or None
+        """
+        def _get_pem() -> Tuple[Optional[PEM], str, bool]:
+            text, ok = self.receiver_client.receiver_request.get(f"/pem/{pem_id}")
+            if not ok:
+                return None, text, False
+            pem_json = json.loads(text)
+            pem = PEMSerialization.from_dict(pem_json, True)
+            return pem, 'OK', True
+
+        return _handle_request(_get_pem, "Getting pem")
+
     def get_pems(self,
                  page_index: int = -1,
                  page_size: int = -1,
@@ -257,24 +293,29 @@ class RKAdmin:
         return artifacts, "", True
 
     def _get_artifacts_from_graph(self) -> Tuple[List[Artifact], str, bool]:
-        text, ok = self.query_graph('MATCH (a:Artifact) RETURN a.rk_id AS rk_id, a.properties as properties')
+        text, ok = self.query_graph('MATCH (a:Artifact) RETURN a.rk_id AS rk_id, a.properties as properties, a.created_at as created_at')
         if not ok:
             return [], text, False
 
         # the text contains python like list [['<name>','<properties-as-json>'], ['<name>', ... ] ]
         objs = ast.literal_eval(text)
         artifacts: List[Artifact] = [
-            ArtifactSerialization.from_dict(
-                {'Name': o[0],
-                 'Properties': json.loads(o[1]) if o[1] else {},
-                 'CreatedAt': None,
-                 'TaxonomyFiles': None}
-            )
+            create_artifact_from_neo4j(o)
             for o in objs
         ]
         return artifacts, "", True
 
 
+def create_artifact_from_neo4j(result: tuple) -> Artifact:
+    art = ArtifactSerialization.from_dict(
+        {'Name': result[0],
+         'Properties': json.loads(result[1]) if result[1] else {},
+         'CreatedAt': result[2],
+         'TaxonomyFiles': None}
+    )
+    return art
+
+
 def _handle_request(func: Callable, name: str) -> Tuple[Any, str, bool]:
     """
     Wraps the error, logging and exception handling.
