@@ -2,7 +2,7 @@ import time
 import logging
 import datetime
 from uuid import UUID, uuid1
-from typing import Dict, Any, Optional, Tuple, Callable
+from typing import Dict, Optional, Tuple, Callable
 from importlib.metadata import version
 
 from rkclient.auth import RK_USER_AUTH_HEADER, RK_PUC_AUTH_HEADER
@@ -14,28 +14,6 @@ log = logging.getLogger("rkclient")
 RK_VERSION = version('RecordKeeper_Client')
 
 
-def add_pem_context(files: Dict[str, Any], pem: PEM):
-    """
-    Helper function to be used when adding RK context to request
-    :param files: a dictionary which belongs to Python Requests object
-    :return:
-    """
-    files['rk_context'] = pem.ID.hex
-
-
-def get_pem_from_request(request) -> Optional[UUID]:
-    """
-    Helper function to be used when retrieving RK context
-    :param request: Flask-request object
-    :return:
-    """
-    rk_context = request.files.get('rk_context', None)
-    if rk_context is None:
-        return None
-    pem_id: str = rk_context.stream.read().decode("UTF8")
-    return UUID(hex=pem_id)
-
-
 class RKClient:
     """
         All network functions return tuple [str, bool]
@@ -59,7 +37,7 @@ class RKClient:
         """
 
         receiver_url = receiver_url.rstrip('/')
-        self.receiver_request = RequestHelper(receiver_url, timeout_sec, insecure, user_auth, puc_auth)
+        self.receiver_request = RequestHelper(receiver_url, timeout_sec, insecure, user_auth, puc_auth, f'recordkeeper-client-{RK_VERSION}')
         log.info(f"ver {RK_VERSION}, connecting to: {receiver_url}")
 
         self.emitter_id = emitter_id
@@ -134,7 +112,7 @@ class RKClient:
 
     def get_info(self) -> Tuple[str, bool]:
         """
-        Returns json with fields as in Info class. Use `deserialize_info` for easy parsing.
+        Returns json with fields as in Info class - the Receiver state. Use `deserialize_info` for easy parsing.
         :return: check class description
         """
         def _get_info():
